@@ -35,7 +35,7 @@
       CALL GRSTRN( 4 )
       CALL GRSTRF
 
-      CALL USSTTL( 'FREQUENCY', '/s', 'POWER', 'm|2"/s|2"' )
+      CALL USSTTL( 'FREQUENCY', '/s', 'POWER', 'm\^{2}/s\^{2}' )
       CALL USDAXS
 
       CALL UULIN( NMAX, X, Y )
