@@ -17,7 +17,7 @@
 
       XMAXF = 26.
       YMAXF = 18.5
-      CALL SLFORM(XMAXF, YMAXF)        ! <-- Ūѻ礭
+      CALL SLFORM(XMAXF, YMAXF)        ! <-- 絶対的な用紙の大きさを指定
       CALL SLRAT(XMAXF, YMAXF)
 
       CALL SGLSET('LFULL', .TRUE.)
