@@ -21,7 +21,7 @@
       CALL GROPN( IWS )
       CALL GRFRM
 
-      CALL USSTTL( 'TIME', 'YEAR', 'HEAT FLUX', 'W/m|2"' )
+      CALL USSTTL( 'TIME', 'YEAR', 'HEAT FLUX', 'W/m\^2' )
       CALL USGRPH( NMAX+1, X, Y )
 
       CALL GRCLS
