@@ -10,6 +10,7 @@ int main (int argc, char *argv[])
     int i, np;
     char carg[40], cmd[200], *cpar, *ceq;
     int toupper();
+    int retv;
 
     if (argc < 2) {
 	printf ("Usage: dclexec command options...\n");
@@ -32,6 +33,6 @@ int main (int argc, char *argv[])
 	}
 	strcat (cmd, " ");
 	strcat (cmd, argv[1]);
-	system (cmd);
+	retv=system (cmd);
     }
 }
