@@ -11,7 +11,7 @@
       CHARACTER COBJ*(*), COMM*(*)
 
       LOGICAL   LWAIT, LWAIT0, LWAIT1, LKEY, LDUMP, LALT,
-     +          LCOLOR, LSEP, LPRINT, LFGBG, LOPEN
+     +          LCOLOR, LSEP, LPRINT, LFGBG, LOPEN, LCLIP
       CHARACTER CMSG*80, CLRMAP*80, CBTMAP*80, CLPR*80, COUT*80,
      +          CTTL*80, CMAP*80, DSPATH*80
       LOGICAL   LWND
@@ -24,6 +24,19 @@
 
       REAL      RLWFACT
 
+      LOGICAL   LFPROP, LCNTL
+      INTEGER   ISUP, ISUB, IRST
+      REAL      SMALL, SHIFT
+
+      REAL VXMIN,VXMAX,VYMIN,VYMAX
+      REAL WXMIN,WXMAX,WYMIN,WYMAX
+
+      LOGICAL LVAL
+      INTEGER   IVAL
+      REAL RVAL
+
+      INTEGER FNTNUM
+
       SAVE
 
       DATA      CNOPN / 'WORKSTATION IS NOT OPENED.' /
@@ -95,6 +108,22 @@
 
         CALL SWRGET('RLWFACT', RLWFACT)
 
+        CALL SGLGET('LFPROP ', LFPROP)
+        CALL SGLGET('LCNTL  ', LCNTL )
+        CALL SGIGET('ISUP   ', ISUP  )
+        CALL SGIGET('ISUB   ', ISUB  )
+        CALL SGIGET('IRST   ', IRST  )
+        CALL SGRGET('SMALL  ', SMALL )
+        CALL SGRGET('SHIFT  ', SHIFT )
+
+        CALL ZGLSET('lfprop  ',LENZ('lfprop'),LFPROP)
+        CALL ZGLSET('lcntl   ',LENZ('lcntl') ,LCNTL)
+        CALL ZGISET('isup    ',LENZ('isup')  ,ISUP)
+        CALL ZGISET('isub    ',LENZ('isub')  ,ISUB)
+        CALL ZGISET('irst    ',LENZ('irst')  ,IRST)
+        CALL ZGRSET('small   ',LENZ('small') ,SMALL)
+        CALL ZGRSET('shift   ',LENZ('shift') ,SHIFT)
+
         CALL ZGDOPN(JWS, IWIDTH, IHEIGH, IPOSX, IPOSY, IDMPDGT,
      +       IBGPAGE,RLWFACT,
      +       LWAIT, LWAIT0, LWAIT1, LALT, LSTDOT,LKEY, LDUMP, LWND,
@@ -131,6 +160,14 @@
      +   CALL MSGDMP('E', 'SWPOPN', CNOPN)
       CALL ZGPOPN
 
+      RETURN
+*-----------------------------------------------------------------------
+      ENTRY SWFLSH
+
+*     / PAGE FLASH EXPLICIT /
+
+      CALL ZGFLASH()
+
       RETURN
 *-----------------------------------------------------------------------
       ENTRY SWPCLS
@@ -217,6 +254,15 @@
       CALL ZGSLCL(ICOLOR)
 
       RETURN
+*-----------------------------------------------------------------------
+      ENTRY SWSFW(IWIDX)
+
+*     / SET FONT WEIGHT /
+
+      CALL ZGSFW(IWIDX)
+
+      RETURN
+
 *-----------------------------------------------------------------------
 *     OPEN
 *-----------------------------------------------------------------------
@@ -436,5 +482,97 @@
       CALL ZGCLINI(CLRMAP,LFGBG)
 
       RETURN
+*-----------------------------------------------------------------------
+*     TEXT
+*-----------------------------------------------------------------------
+      ENTRY SWQTXW(CHARS,NCHZ,WXCH,WYCH)
+
+*       / PASS SG* PARAMETERS TO ZGPACK /
+      CALL SGLGET('LCNTL',LCNTL)
+      CALL ZGLSET('lcntl ',LENZ('lcntl'), LCNTL)
+      IF (LCNTL) THEN
+        CALL SGIGET('ISUB', ISUB)
+        CALL SGIGET('ISUP', ISUP)
+        CALL SGIGET('IRST', IRST)
+        CALL SGRGET('SMALL', SMALL)
+        CALL SGRGET('SHIFT', SHIFT)
+        CALL ZGISET('isub ',LENZ('isub'), ISUB)
+        CALL ZGISET('isup ',LENZ('isup'), ISUP)
+        CALL ZGISET('irst ',LENZ('irst'), IRST)
+        CALL ZGRSET('small ',LENZ('small'), SMALL)
+        CALL ZGRSET('shift ',LENZ('shift'), SHIFT)
+      END IF
+
+      CALL ZGQTXW(CHARS,NCHZ,WXCH,WYCH)
+
+      RETURN
+*-----------------------------------------------------------------------
+      ENTRY SWFTFC(FONTNAME)
+
+      CALL ZGFTFC(FONTNAME)
+
+      RETURN
+
+*-----------------------------------------------------------------------
+      ENTRY SWFTNM(FNTNUM)
+
+      CALL ZGNUMFONTS(FNTNUM)
+
+      RETURN
+
+*-----------------------------------------------------------------------
+      ENTRY SWSLFT(FONTNAME)
+      IF(IWS.EQ.2 .AND. IFL.NE.1) THEN
+        CALL MSGDMP('M','SWSLFT',
+     *    'DIALOG NEEDS WINDOW.DEFAULT FONT IS USED')
+      ELSE
+        CALL ZGSELECTFONT(FONTNAME)
+      END IF
+
+      RETURN
+
+*-----------------------------------------------------------------------
+      ENTRY SWGTFT(INUM,FONTNAME,IFMAX)
+
+      CALL ZGFONTNAME(INUM,FONTNAME,IFMAX)
+
+      RETURN
+
+*-----------------------------------------------------------------------
+      ENTRY SWLSFT()
+
+      CALL ZGLISTFONTS()
+
+      RETURN
+
+*-----------------------------------------------------------------------
+      ENTRY SWTXT(WX,WY,QSIZEXRATE,CHARS,NCZ,IROTA,ICENTZ)
+
+      CALL SGPGET('LCLIP',LCLIP)
+      CALL ZGRCLP()
+      IF (LCLIP) THEN
+        CALL SGQVPT(VXMIN,VXMAX,VYMIN,VYMAX)
+        CALL STFWTR(VXMIN,VYMIN,WXMIN,WYMIN)
+        CALL STFWTR(VXMAX,VYMAX,WXMAX,WYMAX)
+        CALL ZGCLIP(WXMIN,WXMAX,WYMIN,WYMAX)
+      ENDIF
+*       / PASS SG* PARAMETERS TO ZGPACK /
+      CALL SGLGET('LCNTL',LCNTL)
+      CALL ZGLSET('lcntl ',LENZ('lcntl'), LCNTL)
+      IF (LCNTL) THEN
+        CALL SGIGET('ISUB', ISUB)
+        CALL SGIGET('ISUP', ISUP)
+        CALL SGIGET('IRST', IRST)
+        CALL SGRGET('SMALL', SMALL)
+        CALL SGRGET('SHIFT', SHIFT)
+        CALL ZGISET('isub ',LENZ('isub'), ISUB)
+        CALL ZGISET('isup ',LENZ('isup'), ISUP)
+        CALL ZGISET('irst ',LENZ('irst'), IRST)
+        CALL ZGRSET('small ',LENZ('small'), SMALL)
+        CALL ZGRSET('shift ',LENZ('shift'), SHIFT)
+      END IF
+
+      CALL ZGTXT(WX,WY,QSIZEXRATE,CHARS,NCZ,IROTA,ICENTZ)
+      RETURN
 
       END
