@@ -11,8 +11,11 @@
       PARAMETER (WUNIT=24)
 
       REAL      WX1(NWX),WX2(NWX)
-      LOGICAL   LCNTL
+      LOGICAL   LCNTL, SYSFONT, LFPROP, MARKFONT
       CHARACTER CSGI*1,CSUP*1,CSUB*1,CRST*1
+      CHARACTER FONTNAME*70
+      REAL      SMALL, SHIFT
+      INTEGER   ISUB, ISUP, IRST, IFONT, INDEX
 
       EXTERNAL  LENC,INDXCF,NINDXC,CSGI,ISGC
 
@@ -31,6 +34,45 @@
 
       NCHZ=LENC(CHARS)
 
+
+*     / FOR SYSTEM FONTS /
+*     / PROCCESS IF NOT MARKER /
+      CALL SWLGET("SYSFONT", SYSFONT)
+      IF(SYSFONT) THEN
+      CALL SZQIDX(INDEX)
+      CALL SWCGET("FONTNAME",FONTNAME)
+*     / WHEN FONTNAME IS NOT GIVEN /
+      IF (LENZ(FONTNAME) == 0) THEN
+        CALL SGLGET('LFPROP', LFPROP)
+        IF (LFPROP) THEN
+          CALL SGIGET('IFONT', IFONT)
+          IF(IFONT.EQ.1)THEN
+            FONTNAME = 'Sans'
+          ELSE IF (IFONT.EQ.2)THEN
+            FONTNAME = 'Serif'
+          END IF
+        ELSE
+          FONTNAME = 'Monospace'
+        END IF
+        CALL SWFTFC(FONTNAME)
+        CALL SWSFW(MAX(MOD(INDEX,10),1))
+      ELSE
+        CALL SWFTFC(FONTNAME)
+      END IF
+
+
+      IDX=ISGC(CHARS(1:1))
+      CALL SGLGET('MARKFONT',MARKFONT)
+      IF (IDX.GT.18 .OR. MARKFONT) THEN
+        IF (IDX.LT.18) THEN
+          CALL SWSFW(MAX(MOD(INDEX,10),1))
+        END IF
+        CALL SWQTXW(CHARS,NCHZ,WXCH,WYCH)
+        GO TO 40
+      END IF
+      END IF
+
+
 *     / CHECK LCNTL OPTION /
 
       CALL SGLGET('LCNTL',LCNTL)
@@ -137,4 +179,7 @@
 
       END IF
 
+  40  CONTINUE
+
+
       END
