@@ -1,3 +1,5 @@
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE ULXLOG ( CSIDE, NLBL, NTICKS )
 
@@ -7,14 +9,11 @@
 
       PARAMETER(MAXL=50,MAXS=200)
       DIMENSION BL(10),BS(10),UX1(MAXS),UX2(MAXL),UXT(MAXL)
-      CHARACTER CH(MAXL)*16,CHR*8,CFMT*16,CXFMT*16,CSGI,CSIDE
-      LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUXCHK
+      CHARACTER CH(MAXL)*16,CHR*8,CFMT*16,CSGI,CSIDE,CHW*16
+      LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUXCHK,LOFF,LSFNT
 
       SAVE
 
-      DATA CFMT/'B'/
-
-
       IF(.NOT.LUXCHK(CSIDE))
      #   CALL MSGDMP('E', 'ULXLOG', 'INVALID CSIDE.')
       IF(NLBL.LT.1 .OR. NLBL.GT.4)
@@ -22,8 +21,23 @@
       IF(NTICKS.LT.1 .OR. NTICKS.GT.9)
      #   CALL MSGDMP('E', 'ULXLOG', 'INVALID NTICKS.')
 
-      CALL SGQWND(XMIN,XMAX,UY1,UY2)
-      IF(XMIN.GT.XMAX)THEN
+      CALL SGQWND(UXMIN,UXMAX,UYMIN,UYMAX)
+
+      CALL UZLGET('LOFFSET', LOFF)
+      IF(LOFF) THEN
+        CALL UZRGET('XFACT',   FACTOR)
+        XMIN = UXMIN/FACTOR
+        XMAX = UXMAX/FACTOR
+        CALL SGSWND(XMIN,XMAX,UYMIN,UYMAX)
+        CALL SGSTRF
+      ELSE
+        XMIN = UXMIN
+        XMAX = UXMAX
+      ENDIF
+
+      SGN = SIGN(1.0,XMIN)
+
+      IF(SGN*XMIN.GT.SGN*XMAX)THEN
         XXX=XMIN
         XMIN=XMAX
         XMAX=XXX
@@ -33,8 +47,12 @@
       CALL ULIGET('IXCHR' , IXCHR)
       CALL ULXLBL( BL, NB , NLBL)
 
+      CALL SGIGET('ISUP', ISUP)
+      CALL SGIGET('IRST', IRST)
+
       CALL GLLGET('LEPSL',LEPSL)
       CALL SGLGET('LCNTL',LCNTL)
+      CALL SWLGET('SYSFONT',LSFNT)
       CALL GLLSET('LEPSL',.TRUE.)
       CALL GNSAVE
 
@@ -43,8 +61,8 @@
       CALL VRGNN(BS, 10, 1)
       BS(NTICKS+1)=10.
       CALL GNSBLK(BS,NTICKS+1)
-      CALL GNLE(XMAX,BXMAX,IPMAX)
-      CALL GNGE(XMIN,BXMIN,IPMIN)
+      CALL GNLE(ABS(XMAX),BXMAX,IPMAX)
+      CALL GNGE(ABS(XMIN),BXMIN,IPMIN)
 
       NBS=0
       DO 100 IP=IPMIN,IPMAX
@@ -53,14 +71,14 @@
         IF(IP.EQ.IPMAX.AND.LRGT(BS(IB),BXMAX))GOTO 100
         NBS=NBS+1
         IF(NBS.GT.MAXS) CALL MSGDMP('E', 'ULXLOG', 'TOO MANY TICKS.')
-        UX1(NBS)=BS(IB)*10.**IP
+        UX1(NBS)=SGN*BS(IB)*10.**IP
   100 CONTINUE
 
 *     LARGE LABELS AND TICKS
 
       CALL GNSBLK(BL,NB+1)
-      CALL GNLE(XMAX,BXMAX,IPMAX)
-      CALL GNGE(XMIN,BXMIN,IPMIN)
+      CALL GNLE(ABS(XMAX),BXMAX,IPMAX)
+      CALL GNGE(ABS(XMIN),BXMIN,IPMIN)
 
       NBL=0
       NBT=0
@@ -73,12 +91,12 @@
 
         IF(IB.EQ.1)THEN
           NBT=NBT+1
-          UXT(NBT)=10.**IP
+          UXT(NBT)=SGN*10.**IP
         END IF
 
         NBL=NBL+1
         IF(NBL.GT.MAXL) CALL MSGDMP('E', 'ULXLOG', 'TOO MANY LABELS.')
-        UX2(NBL)=BL(IB)*10.**IP
+        UX2(NBL)=SGN*BL(IB)*10.**IP
 
         IF(ITYPE.LE.2) THEN
           IF(JTYPE.EQ.0 .AND. IB.NE.1) THEN
@@ -93,7 +111,13 @@
             WRITE(CHR,'(I8)') IP
             CALL CLADJ(CHR)
             IF(LCNTL) THEN
-              CH(NBL)(3:16)='10|'//CHR(1:LENZ(CHR))//'"'
+*              IF(LSFNT) THEN
+                CH(NBL)(3:16)='10'//'\^{'//CHR(1:LENZ(CHR))
+     +            //'}'
+*              ELSE
+*                CH(NBL)(3:16)='1x'//CSGI(ISUP)//CHR(1:LENZ(CHR))
+*     +            //CSGI(IRST)
+*              END IF
             ELSE
               CH(NBL)(2:16)='E'//CHR
             ENDIF
@@ -104,12 +128,20 @@
           IF(JTYPE.EQ.0 .AND. IB.NE.1) THEN
             WRITE(CH(NBL),'(I1)') INT(BL(IB))
           ELSE
-            CALL CHVAL(CFMT, UX2(NBL), CH(NBL))
+            CALL UZCGET('CXFMT', CFMT)
+            CALL CHVAL(CFMT, ABS(UX2(NBL)), CH(NBL))
             CALL CLADJ(CH(NBL))
           ENDIF
         ENDIF
   201 CONTINUE
 
+      IF(SGN.LT.0) THEN
+         DO 301 IB=1,NBL
+            CHW='-'//CH(IB)
+            CH(IB)=CHW
+  301    CONTINUE
+      ENDIF
+
 *     DRAW AXIS, TICKS, AND LABELS
 
       CALL UXPAXS(CSIDE,2)
@@ -121,21 +153,9 @@
       CALL GLLSET('LEPSL',LEPSL)
       CALL GNRSET
 
-      RETURN
-*-----------------------------------------------------------------------
-      ENTRY ULXSFM ( CXFMT )
+      IF (LOFF) THEN
+        CALL SGSWND(UXMIN,UXMAX,UYMIN,UYMAX)
+        CALL SGSTRF
+      ENDIF
 
-*     SET FORMAT FOR IXTYPE=3 OR 4
-
-      CFMT=CXFMT
-
-      RETURN
-*-----------------------------------------------------------------------
-      ENTRY ULXQFM ( CXFMT )
-
-*     GET FORMAT FOR IXTYPE=3 OR 4
-
-      CXFMT=CFMT
-
-      RETURN
       END
