@@ -10,7 +10,7 @@
       PARAMETER(MAXL=50,MAXS=200)
       DIMENSION BL(10),BS(10),UY1(MAXS),UY2(MAXL),UYT(MAXL)
       CHARACTER CH(MAXL)*16,CHR*8,CFMT*16,CSGI,CSIDE,CHW*16
-      LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUYCHK,LOFF
+      LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUYCHK,LOFF,LSFNT
 
       SAVE
 
@@ -52,6 +52,7 @@
 
       CALL GLLGET('LEPSL',LEPSL)
       CALL SGLGET('LCNTL',LCNTL)
+      CALL SWLGET('SYSFONT',LSFNT)
       CALL GLLSET('LEPSL',.TRUE.)
       CALL GNSAVE
 
@@ -110,8 +111,13 @@
             WRITE(CHR,'(I8)') IP
             CALL CLADJ(CHR)
             IF(LCNTL) THEN
-              CH(NBL)(3:16)='10'//CSGI(ISUP)//CHR(1:LENZ(CHR))
-     +          //CSGI(IRST)
+*              IF(LSFNT) THEN
+                CH(NBL)(3:16)='10'//'\^{'//CHR(1:LENZ(CHR))
+     +            //'}'
+*              ELSE
+*                CH(NBL)(3:16)='10'//CSGI(ISUP)//CHR(1:LENZ(CHR))
+*     +            //CSGI(IRST)
+*              END IF
             ELSE
               CH(NBL)(2:16)='E'//CHR
             ENDIF
